@@ -1161,7 +1161,7 @@ DrawFrame(tw)
 	Dimension	ch = tw->tabs.child_height ;
 
 	Draw3dBox((Widget)tw, 0,tw->tabs.tab_total,
-		tw->core.width, ch+2*s, s, topgc, botgc) ;
+		tw->core.width, ch+2*s, s, topgc, botgc, topgc, botgc) ;
 }
 
 
